================================================
:mod:`tensor.rewriting.basic` -- Tensor Rewrites
================================================

.. module:: tensor.rewriting.basic
   :platform: Unix, Windows
   :synopsis: Tensor Rewrites
.. moduleauthor:: LISA, PyMC Developers, Aesara Developers

.. automodule:: aesara.tensor.rewriting.basic
    :members:
